#ifndef UDE_SETTINGS_H
#define UDE_SETTINGS_H

#include "ude-desktop.h"
#include "ude-box.h"

char ude_update_UDEWorkspaceExchange(UDEDesktop *desk);
char ude_update_UDEDesktop(UDEDesktop *desk);
short ude_get_box_workspace(UDEBox *box);

#endif /* UDE_SETTINGS_H */
